==> foundation-ui-components-1.25.0.tgz: package/src/common/card/NsBrandCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsTypography } from '../';
import NsBrandWrapper from './NsBrandWrapper';
import NsBrandLogo from './NsBrandLogo';
import NsBgCard from './NsBgCard';
import cardSizes from './cardSizes';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsBrandCardProps = {
    title?: string;
    brandImageUrl: string;
    backgroundImageUrl: string;
    size?: 'small' | 'large';
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ size }) => {
    const { small, large } = cardSizes;
    let maxWidth, maxHeight;

    if (size === 'small') {
        maxWidth = small.maxWidth;
        maxHeight = small.maxHeight;
    } else {
        maxWidth = large.maxWidth;
        maxHeight = large.maxHeight;
    }

    return {
        maxWidth,
        display: 'flex',
        alignItems: 'start',
        justifyContent: 'center',
        position: 'relative',
        flexDirection: 'column',
        '.brand-title': {
            marginTop: '15px',
            fontSize: '18px',
            fontWeight: 600,
            lineHeight: '26px',
            display: 'inline-block',
            wordBreak: 'break-word',
        },
        ':hover': {
            '.brand-title': {
                opacity: '0.7',
            },
        },
        '.image': {
            maxWidth,
            maxHeight,
            backgroundSize: 'cover',
            backgroundPosition: 'center',
        },
    };
});
export default function NsBrandCard({
    title,
    brandImageUrl,
    backgroundImageUrl,
    button,
    size,
    className,
}: NsBrandCardProps) {
    return (
        <CardContainer className={className} role="brand-card" component="div" data-testid="brand-card" size={size}>
            <NsBgCard backgroundImageUrl={backgroundImageUrl} className="image">
                <NsBrandWrapper>
                    <NsBrandLogo component="img" image={brandImageUrl} />
                </NsBrandWrapper>
            </NsBgCard>
            {title ? (
                <NsTypography variant="h3" className="brand-title">
                    {title}
                </NsTypography>
            ) : null}
            {button ? <CardButton {...button} /> : null}
        </CardContainer>
    );
}

==> foundation-ui-components-1.30.1.tgz: package/src/common/card/NsBrandCard.tsx <==
import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { NsTypography } from '../';
import CardButton from './CardButton';
import cardSizes from './cardSizes';
import NsBgCard from './NsBgCard';
import NsBrandLogo from './NsBrandLogo';
import NsBrandWrapper from './NsBrandWrapper';
import { NsCardButton } from './types';

type NsBrandCardProps = {
    title?: string;
    brandImageUrl: string;
    backgroundImageUrl: string;
    size?: 'small' | 'large';
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ size }) => {
    const { small, large } = cardSizes;
    let maxWidth, maxHeight;

    if (size === 'small') {
        maxWidth = small.maxWidth;
        maxHeight = small.maxHeight;
    } else {
        maxWidth = large.maxWidth;
        maxHeight = large.maxHeight;
    }

    return {
        maxWidth,
        display: 'flex',
        alignItems: 'start',
        justifyContent: 'center',
        position: 'relative',
        flexDirection: 'column',
        '.brand-title': {
            marginTop: '15px',
            fontSize: '18px',
            fontWeight: 600,
            lineHeight: '26px',
            display: 'inline-block',
            wordBreak: 'break-word',
        },
        ':hover': {
            '.brand-title': {
                opacity: '0.7',
            },
        },
        '.image': {
            maxWidth,
            maxHeight,
            backgroundSize: 'cover',
            backgroundPosition: 'center',
        },
    };
});
export default function NsBrandCard({
    title,
    brandImageUrl,
    backgroundImageUrl,
    button,
    size,
    className,
}: NsBrandCardProps): ReactElement {
    return (
        <CardContainer className={className} role="brand-card" component="div" data-testid="brand-card" size={size}>
            <NsBgCard backgroundImageUrl={backgroundImageUrl} className="image">
                <NsBrandWrapper>
                    <NsBrandLogo component="img" image={brandImageUrl} />
                </NsBrandWrapper>
            </NsBgCard>
            {title ? (
                <NsTypography variant="h3" className="brand-title">
                    {title}
                </NsTypography>
            ) : null}
            {button ? <CardButton {...button} /> : null}
        </CardContainer>
    );
}
